#This file is part of Tryton.  The COPYRIGHT file at the top level of
#this repository contains the full copyright notices and license terms.
from trytond.model import ModelSQL, ModelView, ModelWorkflow, fields
from trytond.pyson import Not, Equal, Eval, In
from trytond.wizard import Wizard


class Opportunity(ModelWorkflow, ModelSQL, ModelView):
    'Opportunity'
    _description = __doc__
    _name = 'training.opportunity'
    _rec_name = 'description'

    description = fields.Char('Description', required=True, states={
        'readonly': Not(Equal(Eval('state'), 'opportunity')),
        }, depends=['state'])
    start_date = fields.Date('Start Date', required=True, states={
        'readonly': Not(Equal(Eval('state'), 'opportunity')),
        }, depends=['state'])
    end_date = fields.Date('End Date', readonly=True, states={
        'required': In(Eval('state'), ['converted', 'lost']),
        }, depends=['state'])
    party = fields.Many2One('party.party', 'Party', required=True, states={
        'readonly': Not(Equal(Eval('state'), 'opportunity')),
        }, depends=['state'])
    comment = fields.Text('Comment', states={
        'readonly': Not(Equal(Eval('state'), 'opportunity')),
        }, depends=['state'])
    state = fields.Selection([
            ('opportunity', 'Opportunity'),
            ('converted', 'Converted'),
            ('lost', 'Lost'),
        ], 'State', required=True, readonly=True, sort=False)

    def default_start_date(self, cursor, user, context=None):
        date_obj = self.pool.get('ir.date')
        return date_obj.today(cursor, user, context=context)

    def default_state(self, cursor, user, context=None):
        return 'opportunity'

    def workflow_opportunity(self, cursor, user, record_id, context=None):
        return self.write(cursor, user, record_id, {'state': 'opportunity'},
                context=context)

    def workflow_converted(self, cursor, user, record_id, context=None):
        date_obj = self.pool.get('ir.date')
        return self.write(cursor, user, record_id, {
            'state': 'converted',
            'end_date': date_obj.today(cursor, user, context=context),
            }, context=context)

    def workflow_lost(self, cursor, user, record_id, context=None):
        date_obj = self.pool.get('ir.date')
        return self.write(cursor, user, record_id, {
            'state': 'lost',
            'end_date': date_obj.today(cursor, user, context=context),
            }, context=context)

Opportunity()


class ConvertOppotunitiesInit(ModelView):
    'Convert Opportunities Init'
    _name = 'training.opportunity.convert.init'
    _description = __doc__

ConvertOppotunitiesInit()


class ConvertOppotunities(Wizard):
    'Convert Opportunities'
    _name = 'training.opportunity.convert'
    states = {
        'init': {
            'result': {
                'type': 'form',
                'object': 'training.opportunity.convert.init',
                'state': [
                    ('end', 'Cancel', 'tryton-cancel'),
                    ('convert', 'Convert', 'tryton-ok', True),
                ],
            },
        },
        'convert': {
            'actions': ['_convert'],
            'result': {
                'type': 'state',
                'state': 'end',
            },
        },
    }

    def _convert(self, cursor, user, data, context=None):
        opportunity_obj = self.pool.get('training.opportunity')
        opportunity_obj.workflow_trigger_validate(cursor, user, data['ids'],
                'convert', context=context)
        return {}

ConvertOppotunities()
